pub struct Debug { /* private fields */ }Implementations
Sourceimpl Debug
impl Debug
pub const PICT_INFO: Debug
pub const RC: Debug
pub const BITSTREAM: Debug
pub const MB_TYPE: Debug
pub const QP: Debug
pub const DCT_COEFF: Debug
pub const SKIP: Debug
pub const STARTCODE: Debug
pub const ER: Debug
pub const MMCO: Debug
pub const BUGS: Debug
pub const BUFFERS: Debug
pub const THREADS: Debug
pub const NOMC: Debug
Sourcepub fn from_bits(bits: c_int) -> Option<Debug>
pub fn from_bits(bits: c_int) -> Option<Debug>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
Sourcepub const fn from_bits_truncate(bits: c_int) -> Debug
pub const fn from_bits_truncate(bits: c_int) -> Debug
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
Sourcepub const unsafe fn from_bits_unchecked(bits: c_int) -> Debug
pub const unsafe fn from_bits_unchecked(bits: c_int) -> Debug
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
Sourcepub const fn intersects(&self, other: Debug) -> bool
pub const fn intersects(&self, other: Debug) -> bool
Returns true if there are flags common to both self and other.